@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
-from collective import dexteritytextindexer
 from collective.address.behaviors import IAddress
-from plone.dexterity.interfaces import IDexterityContent
 from design.plone.contenttypes import _
+from plone.app.dexterity import textindexer
 from plone.autoform.interfaces import IFormFieldProvider
+from plone.dexterity.interfaces import IDexterityContent
 from plone.supermodel import model
-from zope.component import adapter
 from zope import schema
-from zope.interface import provider, implementer
-from design.plone.contenttypes.interfaces.unita_organizzativa import IUnitaOrganizzativa
+from zope.component import adapter
+from zope.interface import implementer
+from zope.interface import provider
 
 
 class IAddressNomeSede(model.Schema):
@@ -21,7 +21,7 @@ class IAddressNomeSede(model.Schema):
         ),
         required=False,
     )
-    dexteritytextindexer.searchable("nome_sede")
+    textindexer.searchable("nome_sede")
 
 
 class IAddressLocal(model.Schema):
@@ -40,26 +40,8 @@ class IAddressLocal(model.Schema):
     )
 
     # searchabletext indexer
-    dexteritytextindexer.searchable("quartiere")
-    dexteritytextindexer.searchable("circoscrizione")
-
-
-@provider(IFormFieldProvider)
-class IAddressUnitaOrganizzativa(IAddress, IAddressNomeSede, IAddressLocal):
-
-    model.fieldset(
-        "contatti",
-        label=_("contatti_label", default="Contatti"),
-        fields=[
-            "nome_sede",
-            "street",
-            "zip_code",
-            "city",
-            "quartiere",
-            "circoscrizione",
-            "country",
-        ],
-    )
+    textindexer.searchable("quartiere")
+    textindexer.searchable("circoscrizione")
 
 
 @provider(IFormFieldProvider)
@@ -99,15 +81,6 @@ class IAddressEvent(IAddress, IAddressNomeSede, IAddressLocal):
     )
 
 
-@implementer(IAddressUnitaOrganizzativa)
-@adapter(IUnitaOrganizzativa)
-class AddressUnitaOrganizzativa(object):
-    """ """
-
-    def __init__(self, context):
-        self.context = context
-
-
 @implementer(IAddressVenue)
 @adapter(IDexterityContent)
 class AddressVenue(object):
