@@ -5,15 +5,16 @@ from plone.autoform import directives as form
 from plone.autoform.interfaces import IFormFieldProvider
 from plone.dexterity.interfaces import IDexterityContent
 from plone.supermodel import model
-from z3c.relationfield.schema import RelationChoice, RelationList
+from z3c.relationfield.schema import RelationChoice
+from z3c.relationfield.schema import RelationList
 from zope.component import adapter
-from zope.interface import provider, implementer
+from zope.interface import implementer
+from zope.interface import provider
 
 
 # TODO: merge with NEWS
 @provider(IFormFieldProvider)
 class IDatasetCorrelati(model.Schema):
-
     dataset_correlati = RelationList(
         title=_("dataset_correlati_label", default="Dataset correlati"),
         description=_(
