@@ -1,21 +1,65 @@
 # -*- coding: utf-8 -*-
-from collective import dexteritytextindexer
 from collective.volto.blocksfield.field import BlocksField
+from collective.z3cform.datagridfield.datagridfield import DataGridFieldFactory
+from collective.z3cform.datagridfield.row import DictRow
 from design.plone.contenttypes import _
 from design.plone.contenttypes.interfaces import IDesignPloneContentType
+from plone.app.dexterity import textindexer
+from plone.app.z3cform.widget import DateFieldWidget
 from plone.app.z3cform.widget import RelatedItemsFieldWidget
 from plone.autoform import directives as form
+from plone.namedfile import field
 from plone.supermodel import model
 from z3c.relationfield.schema import RelationChoice
 from z3c.relationfield.schema import RelationList
 from zope import schema
 
 
+class ITempiEScadenzeValueSchema(model.Schema):
+    milestone = schema.TextLine(
+        title=_("milestone_label", default="Titolo"),
+        required=False,
+        default="",
+    )
+    milestone_description = schema.TextLine(
+        title=_("milestone_description_label", default="Sottotitolo"),
+        required=False,
+        default="",
+    )
+    interval_qt = schema.TextLine(
+        title=_("interval_qt_label", default="Intervallo"),
+        description=_(
+            "interval_qt_help",
+            default="Intervallo della fase (es. 1)",
+        ),
+        required=False,
+        default="",
+    )
+    interval_type = schema.TextLine(
+        title=_("interval_type_label", default="Tipo intervallo"),
+        description=_(
+            "interval_type_help",
+            default="Ad esempio: " "ore, giorni, settimane, mesi.",
+        ),
+        required=False,
+        default="",
+    )
+    data_scadenza = schema.Date(
+        title=_("data_scadenza_label", default="Data scadenza"),
+        required=False,
+    )
+
+    form.widget(
+        "data_scadenza",
+        DateFieldWidget,
+    )
+
+
 class IServizio(model.Schema, IDesignPloneContentType):
     """Marker interface for content type Servizio"""
 
     sottotitolo = schema.TextLine(
-        title=_(u"sottotitolo_label", default=u"Sottotitolo"),
+        title=_("sottotitolo_label", default="Sottotitolo"),
         description=_(
             "sottotitolo_help",
             default="Indica un eventuale sottotitolo/titolo alternativo.",
@@ -27,29 +71,29 @@ class IServizio(model.Schema, IDesignPloneContentType):
     # solo se il servizio
     # non e' attivo
     stato_servizio = schema.Bool(
-        title=_(u"stato_servizio_label", default=u"Servizio non attivo"),
+        title=_("stato_servizio_label", default="Servizio non fruibile"),
         required=False,
         description=_(
             "stato_servizio_help",
-            default="Indica se il servizio è effettivamente fruibile.",
+            default="Indica se il servizio è effettivamente fruibile; spuntare se non è fruibile.",  # noqa
         ),
     )
 
     motivo_stato_servizio = BlocksField(
         title=_(
-            u"motivo_stato_servizio_label",
-            default=u"Motivo dello stato del servizio nel caso non sia attivo",
+            "motivo_stato_servizio_label",
+            default="Motivo dello stato",
         ),
         required=False,
         description=_(
             "motivo_stato_servizio_help",
-            default="Descrizione del motivo per cui il servizio non è attivo.",
+            default="Descrizione del motivo per cui il servizio non è attivo. È obbligatorio se il campo precedente è spuntato.",  # noqa
         ),
     )
 
     a_chi_si_rivolge = BlocksField(
-        title=_(u"a_chi_si_rivolge_label", default=u"A chi si rivolge"),
-        required=False,
+        title=_("a_chi_si_rivolge_label", default="A chi è rivolto"),
+        required=True,
         description=_(
             "a_chi_si_rivolge_help",
             default="A chi si rivolge questo servizio e chi può usufruirne.",
@@ -57,7 +101,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     chi_puo_presentare = BlocksField(
-        title=_(u"chi_puo_presentare_label", default=u"Chi può presentare"),
+        title=_("chi_puo_presentare_label", default="Chi può presentare"),
         required=False,
         description=_(
             "chi_puo_presentare_help",
@@ -67,7 +111,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     copertura_geografica = BlocksField(
-        title=_(u"copertura_geografica_label", default=u"Copertura geografica"),
+        title=_("copertura_geografica_label", default="Copertura geografica"),
         required=False,
         description=_(
             "copertura_geografica_help",
@@ -77,8 +121,8 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     come_si_fa = BlocksField(
-        title=_(u"come_si_fa", default=u"Come si fa"),
-        required=False,
+        title=_("come_si_fa", default="Come fare"),
+        required=True,
         description=_(
             "come_si_fa_help",
             default="Descrizione della procedura da seguire per poter"
@@ -87,17 +131,17 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     cosa_si_ottiene = BlocksField(
-        title=_(u"cosa_si_ottiene", default=u"Cosa si ottiene"),
+        title=_("cosa_si_ottiene", default="Cosa si ottiene"),
         description=_(
             "cosa_si_ottiene_help",
             default="Indicare cosa si può ottenere dal servizio, ad esempio"
             " 'carta di identità elettronica', 'certificato di residenza'.",
         ),
-        required=False,
+        required=True,
     )
 
     procedure_collegate = BlocksField(
-        title=_(u"procedure_collegate", default=u"Procedure collegate all'esito"),
+        title=_("procedure_collegate", default="Procedure collegate all'esito"),
         required=False,
         description=_(
             "procedure_collegate_help",
@@ -108,27 +152,51 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     canale_digitale = BlocksField(
-        title=_(u"canale_digitale", default=u"Canale digitale"),
+        title=_("canale_digitale", default="Canale digitale"),
         description=_(
             "canale_digitale_help",
+            default="Testo di introduzione del canale digitale",
+        ),
+        required=False,
+    )
+
+    canale_digitale_link = schema.URI(
+        title=_("canale_digitale_link", default="Link al canale digitale"),
+        description=_(
+            "canale_digitale_link_help",
             default="Collegamento con l'eventuale canale digitale di"
             " attivazione del servizio.",
         ),
         required=False,
     )
-
-    autenticazione = BlocksField(
-        title=_(u"autenticazione", default=u"Autenticazione"),
+    # vocabolario dalle unita' organizzative presenti a catalogo?
+    canale_fisico = RelationList(
+        title=_("canale_fisico", default="Canale fisico"),
         description=_(
-            "autenticazione_help",
-            default="Indicare, se previste, le modalità di autenticazione"
-            " necessarie per poter accedere al servizio.",
+            "canale_fisico_help",
+            default="Unità organizzative per la fruizione del servizio",
+        ),
+        required=True,
+        default=[],
+        value_type=RelationChoice(
+            title=_("Canale fisico"),
+            vocabulary="plone.app.vocabularies.Catalog",
         ),
-        required=False,
     )
 
+    # US38344 rimuovere
+    # autenticazione = BlocksField(
+    #     title=_("autenticazione", default="Autenticazione"),
+    #     description=_(
+    #         "autenticazione_help",
+    #         default="Indicare, se previste, le modalità di autenticazione"
+    #         " necessarie per poter accedere al servizio.",
+    #     ),
+    #     required=False,
+    # )
+
     dove_rivolgersi = RelationList(
-        title=u"Dove rivolgersi",
+        title="Dove rivolgersi",
         default=[],
         value_type=RelationChoice(vocabulary="plone.app.vocabularies.Catalog"),
         required=False,
@@ -141,8 +209,8 @@ class IServizio(model.Schema, IDesignPloneContentType):
 
     dove_rivolgersi_extra = BlocksField(
         title=_(
-            u"dove_rivolgersi_extra",
-            default=u"Dove rivolgersi: informazioni aggiuntive",
+            "dove_rivolgersi_extra",
+            default="Dove rivolgersi: informazioni aggiuntive",
         ),
         description=_(
             "dove_rivolgersi_extra_help",
@@ -153,7 +221,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     prenota_appuntamento = BlocksField(
-        title=_(u"prenota_appuntamento", default=u"Prenota un appuntamento"),
+        title=_("prenota_appuntamento", default="Prenota un appuntamento"),
         description=_(
             "prenota_appuntamento_help",
             default="Se è possibile prenotare un'appuntamento, indicare"
@@ -164,8 +232,8 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     tempi_e_scadenze = BlocksField(
-        title=_(u"tempi_e_scadenze", default=u"Tempi e scadenze"),
-        required=False,
+        title=_("tempi_e_scadenze", default="Tempi e scadenze"),
+        required=True,
         description=_(
             "tempi_e_scadenze_help",
             default="Descrivere le informazioni dettagliate riguardo eventuali tempi"
@@ -173,8 +241,25 @@ class IServizio(model.Schema, IDesignPloneContentType):
         ),
     )
 
+    timeline_tempi_scadenze = schema.List(
+        title=_("timeline_tempi_scadenze", default="Timeline tempi e scadenze"),
+        default=[],
+        value_type=DictRow(schema=ITempiEScadenzeValueSchema),
+        description=_(
+            "timeline_tempi_scadenze_help",
+            default="Timeline tempi e scadenze del servizio: indicare per ogni "
+            "scadenza un titolo descrittivo ed un eventuale sottotitolo. "
+            "Per ogni scadenza, selezionare opzionalmente o l'intervallo (Campi"
+            ' "Intervallo" e "Tipo Intervallo", es. "1" e "settimana"),'
+            ' oppure direttamente una data di scadenza (campo: "Data Scadenza"'
+            ", esempio 31/12/2023). "
+            'Se vengono compilati entrambi, ha priorità il campo "Data Scadenza".',
+        ),
+        required=False,
+    )
+
     cosa_serve = BlocksField(
-        title=_(u"cosa_serve", default=u"Cosa serve"),
+        title=_("cosa_serve", default="Cosa serve"),
         required=True,
         description=_(
             "cosa_serve_help",
@@ -183,7 +268,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     costi = BlocksField(
-        title=_(u"costi", default=u"Costi"),
+        title=_("costi", default="Costi"),
         required=False,
         description=_(
             "costi_help",
@@ -193,7 +278,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     vincoli = BlocksField(
-        title=_(u"vincoli", default=u"Vincoli"),
+        title=_("vincoli", default="Vincoli"),
         required=False,
         description=_(
             "vincoli_help",
@@ -202,7 +287,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     casi_particolari = BlocksField(
-        title=_(u"casi_particolari", default=u"Casi particolari"),
+        title=_("casi_particolari", default="Casi particolari"),
         required=False,
         description=_(
             "casi_particolari_help",
@@ -213,7 +298,10 @@ class IServizio(model.Schema, IDesignPloneContentType):
 
     # vocabolario dalle unita' organizzative presenti a catalogo?
     ufficio_responsabile = RelationList(
-        title=_(u"ufficio_responsabile_erogazione", default=u"Uffici responsabili"),
+        title=_(
+            "ufficio_responsabile_erogazione",
+            default="Unità organizzativa responsabile",
+        ),
         description=_(
             "ufficio_responsabile_help",
             default="Seleziona gli uffici responsabili dell'erogazione"
@@ -222,13 +310,13 @@ class IServizio(model.Schema, IDesignPloneContentType):
         required=True,
         default=[],
         value_type=RelationChoice(
-            title=_(u"Ufficio responsabile"),
+            title=_("Unità organizzativa responsabile"),
             vocabulary="plone.app.vocabularies.Catalog",
         ),
     )
 
     area = RelationList(
-        title=_(u"area", default=u"Area"),
+        title=_("area", default="Area"),
         required=False,
         default=[],
         description=_(
@@ -236,12 +324,12 @@ class IServizio(model.Schema, IDesignPloneContentType):
             default="Seleziona l'area da cui dipende questo servizio.",
         ),
         value_type=RelationChoice(
-            title=_(u"Area"), vocabulary="plone.app.vocabularies.Catalog"
+            title=_("Area"), vocabulary="plone.app.vocabularies.Catalog"
         ),
     )
 
     altri_documenti = RelationList(
-        title=u"Documenti correlati",
+        title="Documenti",
         default=[],
         description=_(
             "altri_documenti_help",
@@ -249,13 +337,13 @@ class IServizio(model.Schema, IDesignPloneContentType):
             " a questo servizio.",
         ),
         value_type=RelationChoice(
-            title=_(u"Documento"), vocabulary="plone.app.vocabularies.Catalog"
+            title=_("Documento"), vocabulary="plone.app.vocabularies.Catalog"
         ),
         required=False,
     )
 
     link_siti_esterni = BlocksField(
-        title=_(u"link_siti_esterni", default=u"Link a siti esterni"),
+        title=_("link_siti_esterni", default="Link a siti esterni"),
         required=False,
         description=_(
             "link_siti_esterni_help",
@@ -265,7 +353,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     codice_ipa = schema.TextLine(
-        title=_(u"codice_ipa", default=u"Codice dell'ente erogatore (ipa)"),
+        title=_("codice_ipa", default="Codice dell'ente erogatore (ipa)"),
         required=False,
         description=_(
             "codice_ipa_help",
@@ -277,7 +365,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
 
     # classificazione basata sul catalogo dei servizi, stringa o lista?
     settore_merceologico = schema.TextLine(
-        title=_(u"settore_merceologico", default=u"Settore merceologico"),
+        title=_("settore_merceologico", default="Settore merceologico"),
         required=False,
         description=_(
             "settore_merceologico_help",
@@ -287,7 +375,7 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
 
     identificativo = schema.TextLine(
-        title=_(u"identificativo", default=u"Identificativo"),
+        title=_("identificativo", default="Identificativo"),
         required=False,
         description=_(
             "identificativo_help",
@@ -295,21 +383,34 @@ class IServizio(model.Schema, IDesignPloneContentType):
         ),
     )
 
+    condizioni_di_servizio = field.NamedBlobFile(
+        title=_("condizioni_di_servizio", default="Condizioni di servizio"),
+        required=True,
+    )
+
     servizi_collegati = RelationList(
-        title=u"Servizi collegati",
+        title=_("servizi_collegati_label", default="Servizi collegati"),
+        description=_(
+            "servizi_collegati_help",
+            default="Seleziona la lista dei servizi collegati a questo.",
+        ),
         default=[],
         value_type=RelationChoice(
-            title=_(u"Servizi collegati"),
             vocabulary="plone.app.vocabularies.Catalog",
         ),
         required=False,
-        description=_(
-            "servizi_collegati_help",
-            default="Seleziona la lista dei servizi collegati" " a questo.",
-        ),
     )
 
     # custom widgets
+    form.widget(
+        "canale_fisico",
+        RelatedItemsFieldWidget,
+        vocabulary="plone.app.vocabularies.Catalog",
+        pattern_options={
+            "maximumSelectionSize": 10,
+            "selectableTypes": ["UnitaOrganizzativa"],
+        },
+    )
     form.widget(
         "dove_rivolgersi",
         RelatedItemsFieldWidget,
@@ -335,7 +436,6 @@ class IServizio(model.Schema, IDesignPloneContentType):
         RelatedItemsFieldWidget,
         vocabulary="plone.app.vocabularies.Catalog",
         pattern_options={
-            "maximumSelectionSize": 10,
             "selectableTypes": ["UnitaOrganizzativa"],
             # "basePath": "/amministrazione/uffici",
         },
@@ -360,22 +460,30 @@ class IServizio(model.Schema, IDesignPloneContentType):
             # "basePath": "/",
         },
     )
+    form.widget(
+        "timeline_tempi_scadenze",
+        DataGridFieldFactory,
+        frontendOptions={"widget": "data_grid"},
+    )
 
     # custom fieldset and order
     model.fieldset(
         "a_chi_si_rivolge",
-        label=_("a_chi_si_rivolge_label", default=u"A chi si rivolge"),
+        label=_("a_chi_si_rivolge_label", default="A chi si rivolge"),
         fields=["a_chi_si_rivolge", "chi_puo_presentare", "copertura_geografica"],
     )
+
     model.fieldset(
         "accedi_al_servizio",
-        label=_("accedi_al_servizio_label", default=u"Accedere al servizio"),
+        label=_("accedi_al_servizio_label", default="Accedere al servizio"),
         fields=[
             "come_si_fa",
             "cosa_si_ottiene",
             "procedure_collegate",
             "canale_digitale",
-            "autenticazione",
+            "canale_digitale_link",
+            "canale_fisico",
+            # "autenticazione",
             "dove_rivolgersi",
             "dove_rivolgersi_extra",
             "prenota_appuntamento",
@@ -383,64 +491,66 @@ class IServizio(model.Schema, IDesignPloneContentType):
     )
     model.fieldset(
         "cosa_serve",
-        label=_("cosa_serve_label", default=u"Cosa serve"),
+        label=_("cosa_serve_label", default="Cosa serve"),
         fields=["cosa_serve"],
     )
     model.fieldset(
         "costi_e_vincoli",
-        label=_("costi_e_vincoli_label", default=u"Costi e vincoli"),
+        label=_("costi_e_vincoli_label", default="Costi e vincoli"),
         fields=["costi", "vincoli"],
     )
 
     model.fieldset(
         "tempi_e_scadenze",
-        label=_("tempi_e_scadenze_label", default=u"Tempi e scadenze"),
-        fields=["tempi_e_scadenze"],
+        label=_("tempi_e_scadenze_label", default="Tempi e scadenze"),
+        fields=["tempi_e_scadenze", "timeline_tempi_scadenze"],
     )
 
     model.fieldset(
         "casi_particolari",
-        label=_("casi_particolari_label", default=u"Casi particolari"),
+        label=_("casi_particolari_label", default="Casi particolari"),
         fields=["casi_particolari"],
     )
 
     model.fieldset(
         "contatti",
-        label=_("contatti_label", default=u"Contatti"),
+        label=_("contatti_label", default="Contatti"),
         fields=["ufficio_responsabile", "area"],
     )
     model.fieldset(
         "documenti",
-        label=_("documenti_label", default=u"Documenti"),
+        label=_("documenti_label", default="Documenti"),
         fields=["altri_documenti"],
     )
     model.fieldset(
         "link_utili",
-        label=_("link_utili_label", default=u"Link utili"),
+        label=_("link_utili_label", default="Link utili"),
         fields=["link_siti_esterni"],
     )
 
     model.fieldset(
         "correlati",
-        label=_("correlati_label", default=u"Contenuti collegati"),
+        label=_("correlati_label", default="Contenuti collegati"),
         fields=["servizi_collegati"],
     )
 
     model.fieldset(
         "categorization",
-        fields=["codice_ipa", "settore_merceologico", "identificativo"],
+        fields=["identificativo"],
     )
 
+    model.fieldset("informazioni", fields=["codice_ipa", "settore_merceologico"])
+
     # SearchableText fields
-    dexteritytextindexer.searchable("sottotitolo")
-    dexteritytextindexer.searchable("a_chi_si_rivolge")
-    dexteritytextindexer.searchable("chi_puo_presentare")
-    dexteritytextindexer.searchable("come_si_fa")
-    dexteritytextindexer.searchable("cosa_si_ottiene")
-    dexteritytextindexer.searchable("cosa_serve")
-    dexteritytextindexer.searchable("area")
-    dexteritytextindexer.searchable("ufficio_responsabile")
-    dexteritytextindexer.searchable("copertura_geografica")
-    dexteritytextindexer.searchable("costi")
-    dexteritytextindexer.searchable("servizi_collegati")
-    dexteritytextindexer.searchable("link_siti_esterni")
+    textindexer.searchable("sottotitolo")
+    textindexer.searchable("a_chi_si_rivolge")
+    textindexer.searchable("chi_puo_presentare")
+    textindexer.searchable("come_si_fa")
+    textindexer.searchable("cosa_si_ottiene")
+    textindexer.searchable("cosa_serve")
+    textindexer.searchable("area")
+    textindexer.searchable("ufficio_responsabile")
+    textindexer.searchable("copertura_geografica")
+    textindexer.searchable("costi")
+    textindexer.searchable("servizi_collegati")
+    textindexer.searchable("link_siti_esterni")
