@@ -10,19 +10,20 @@ We need a solution like that because for some different reasons:
    SerializeToJson and SerializeFolderToJson classes
 """
 
-from plone.restapi.serializer.dxcontent import (
-    SerializeToJson,
-    SerializeFolderToJson,
-)
+from collective.taxonomy import PATH_SEPARATOR
+from collective.taxonomy.interfaces import ITaxonomy
 from plone import api
 from plone.restapi.batching import HypermediaBatch
 from plone.restapi.deserializer import boolean_value
 from plone.restapi.interfaces import ISerializeToJson
 from plone.restapi.interfaces import ISerializeToJsonSummary
+from plone.restapi.serializer.dxcontent import SerializeFolderToJson
+from plone.restapi.serializer.dxcontent import SerializeToJson
 from Products.CMFCore.utils import getToolByName
 from zope.component import getMultiAdapter
+from zope.component import getUtility
 from zope.i18n import translate
-from design.plone.contenttypes import _
+
 
 original_serialize_to_json__call__ = SerializeToJson.__call__
 
@@ -32,17 +33,20 @@ def design_italia_serialize_to_json_call(self, version=None, include_items=True)
     result = original_serialize_to_json__call__(
         self, version=version, include_items=include_items
     )
+    result["design_italia_meta_type"] = translate(
+        ttool[self.context.portal_type].Title(), context=self.request
+    )
     if self.context.portal_type == "News Item":
-        result["design_italia_meta_type"] = translate(
-            self.context.tipologia_notizia,
-            domain=_._domain,
-            context=self.request,
-        )
-    else:
-        result["design_italia_meta_type"] = translate(
-            ttool[self.context.portal_type].Title(), context=self.request
-        )
+        if self.context.tipologia_notizia:
+            taxonomy = getUtility(
+                ITaxonomy, name="collective.taxonomy.tipologia_notizia"
+            )
+            taxonomy_voc = taxonomy.makeVocabulary(self.request.get("LANGUAGE"))
 
+            title = taxonomy_voc.inv_data.get(self.context.tipologia_notizia, None)
+
+            if title and title.startswith(PATH_SEPARATOR):
+                result["design_italia_meta_type"] = title.replace(PATH_SEPARATOR, "", 1)
     return result
 
 
