@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
 from AccessControl.unauthorized import Unauthorized
+from Acquisition import aq_inner
 from design.plone.contenttypes.interfaces import IDesignPloneContenttypesLayer
+from design.plone.contenttypes.interfaces.servizio import IServizio
 from plone import api
 from plone.dexterity.interfaces import IDexterityContent
+from plone.namedfile.interfaces import INamedFileField
 from plone.restapi.interfaces import IBlockFieldSerializationTransformer
 from plone.restapi.interfaces import IFieldSerializer
 from plone.restapi.interfaces import ISerializeToJsonSummary
@@ -13,10 +16,12 @@ from zope.component import getMultiAdapter
 from zope.component import subscribers
 from zope.globalrequest import getRequest
 from zope.interface import implementer
+from zope.schema.interfaces import IList
 from zope.schema.interfaces import ISourceText
 
 import json
 
+
 KEYS_WITH_URL = ["linkUrl", "navigationRoot", "showMoreLink"]
 
 
@@ -30,6 +35,54 @@ class SourceTextSerializer(DefaultFieldSerializer):
         return value
 
 
+@implementer(IFieldSerializer)
+@adapter(IList, IServizio, IDesignPloneContenttypesLayer)
+class TempiEScadenzeValueSerializer(DefaultFieldSerializer):
+    def __call__(self):
+        value = super(TempiEScadenzeValueSerializer, self).__call__()
+
+        patched_timeline = []
+        if self.field.getName() == "timeline_tempi_scadenze" and value:
+            for entry in value:
+                patched_timeline.append(entry)
+            return json_compatible(patched_timeline)
+        return value
+
+
+@adapter(INamedFileField, IDexterityContent, IDesignPloneContenttypesLayer)
+class FileFieldViewModeSerializer(DefaultFieldSerializer):
+    """Ovveride the basic DX serializer to handle the visualize file functionality"""
+
+    def __call__(self):
+        namedfile = self.field.get(self.context)
+        if namedfile is None:
+            return
+
+        url = "/".join(
+            (
+                self.context.absolute_url(),
+                self.get_file_view_mode(namedfile.contentType),
+                self.field.__name__,
+            )
+        )
+        result = {
+            "filename": namedfile.filename,
+            "content-type": namedfile.contentType,
+            "size": namedfile.getSize(),
+            "download": url,
+        }
+
+        return json_compatible(result)
+
+    def get_file_view_mode(self, content_type):
+        """Pdf view depends on the visualize_files property in thq aq_chain"""
+        if self.context and "pdf" in content_type:
+            if getattr(aq_inner(self.context), "visualize_files", None):
+                return "@@display-file"
+
+        return "@@download"
+
+
 def serialize_data(context, json_data, show_children=False):
     request = getRequest()
     if not json_data:
