@@ -3,6 +3,9 @@ from design.plone.contenttypes.interfaces.servizio import IServizio
 from design.plone.contenttypes.restapi.serializers.summary import (
     DefaultJSONSummarySerializer,
 )
+from design.plone.contenttypes.restapi.serializers.summary import (
+    get_taxonomy_information,
+)
 from plone.dexterity.utils import iterSchemata
 from plone.restapi.interfaces import IFieldSerializer
 from plone.restapi.interfaces import ISerializeToJsonSummary
@@ -16,11 +19,8 @@ from zope.schema import getFields
 @implementer(ISerializeToJsonSummary)
 @adapter(IServizio, Interface)
 class SerializeServizioToJsonSummary(DefaultJSONSummarySerializer):
-    def __call__(self):
-        """
-        Ritorna sempre una serie di campi extra
-        """
-        summary = super(SerializeServizioToJsonSummary, self).__call__()
+    def __call__(self, force_all_metadata=False):
+        summary = super().__call__(force_all_metadata=force_all_metadata)
         fields = ["canale_digitale"]
         for schema in iterSchemata(self.context):
             for name, field in getFields(schema).items():
@@ -33,4 +33,10 @@ class SerializeServizioToJsonSummary(DefaultJSONSummarySerializer):
                 )
                 value = serializer()
                 summary[name] = value
+
+        parent = self.context.aq_inner.aq_parent
+        summary["parent_title"] = parent.title
+        summary["parent_url"] = parent.absolute_url()
+        get_taxonomy_information("person_life_events", self.context, summary)
+        get_taxonomy_information("business_events", self.context, summary)
         return summary
