@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
-from plone.restapi.services.types.get import TypesGet as BaseGet
-from zope.interface import implementer
-from zope.publisher.interfaces import IPublishTraverse
+from design.plone.contenttypes import _
 from design.plone.contenttypes.controlpanels.geolocation_defaults import (
     IGeolocationDefaults,
 )
-from zope.i18n import translate
 from plone import api
-from design.plone.contenttypes import _
+from plone.restapi.services.types.get import TypesGet as BaseGet
+from zope.i18n import translate
+from zope.interface import implementer
+from zope.publisher.interfaces import IPublishTraverse
 
 
 class FieldsetsMismatchError(Exception):
@@ -51,6 +51,11 @@ FIELDSETS_ORDER = {
         "settings",
         "ownership",
     ],
+    "Incarico": [
+        "default",
+        "informazioni_compensi",
+        "date_e_informazioni",
+    ],
     "News Item": [
         "default",
         "dates",
@@ -89,6 +94,9 @@ FIELDSETS_ORDER = {
         "ownership",
         "settings",
     ],
+    "PuntoDiContatto": [
+        "default",
+    ],
     "Servizio": [
         "default",
         "cose",
@@ -149,7 +157,7 @@ class TypesGet(BaseGet):
 
     def customize_persona_schema(self, result):
         if "title" in result["properties"]:
-            msgid = _(u"Nome e Cognome", default="Nome e cognome")
+            msgid = _("Nome e Cognome", default="Nome e cognome")
             result["properties"]["title"]["title"] = translate(
                 msgid, context=self.request
             )
@@ -159,6 +167,12 @@ class TypesGet(BaseGet):
         """
         Unico modo per spostare il campo "notes"
         """
+        result.get("required").append("description")
+        result.get("required").append("image")
+        result.get("required").append("street")
+        result.get("required").append("city")
+        result.get("required").append("zip_code")
+        result.get("required").append("geolocation")
 
         if "properties" in result:
             if "country" in result["properties"]:
@@ -223,6 +237,40 @@ class TypesGet(BaseGet):
 
         return result
 
+    def customize_servizio_schema(self, result):
+        result.get("required").append("description")
+        return result
+
+    def customize_evento_schema(self, result):
+        result.get("required").append("description")
+        return result
+
+    def customize_uo_schema(self, result):
+        result.get("required").append("description")
+        versioning_fields = ["contact_info"]
+        for field in versioning_fields:
+            for fieldset in result["fieldsets"]:
+                if fieldset.get("id") == "contatti" and field in fieldset["fields"]:
+                    fieldset["fields"].remove(field)
+                    fieldset["fields"].insert(0, field)
+        return result
+
+    def customize_news_schema(self, result):
+        result.get("required").append("description")
+        if self.context.portal_type == "News Item":
+            # we are in a news and not in container
+            review_state = self.context.portal_workflow.getInfoFor(
+                self.context, "review_state"
+            )
+            if review_state == "published":
+                result.get("required").append("effective")
+
+        return result
+
+    def customize_documento_schema(self, result):
+        result.get("required").append("description")
+        return result
+
     def reply(self):
         result = super(TypesGet, self).reply()
 
@@ -241,6 +289,16 @@ class TypesGet(BaseGet):
                 result = self.customize_venue_schema(result)
             if pt == "Document":
                 result = self.customize_document_schema(result)
+            if pt == "Servizio":
+                result = self.customize_servizio_schema(result)
+            if pt == "UnitaOrganizzativa":
+                result = self.customize_uo_schema(result)
+            if pt == "News Item":
+                result = self.customize_news_schema(result)
+            if pt == "Documento":
+                result = self.customize_documento_schema(result)
+            if pt == "Event":
+                result = self.customize_evento_schema(result)
             result = self.customize_versioning_fields_fieldset(result)
         return result
 
