@@ -3,23 +3,27 @@ from plone.app.testing import applyProfile
 from plone.app.testing import FunctionalTesting
 from plone.app.testing import IntegrationTesting
 from plone.testing import z2
-from zope.configuration import xmlconfig
 from redturtle.volto.testing import RedturtleVoltoLayer
 from redturtle.volto.testing import RedturtleVoltoRestApiLayer
-
+from zope.configuration import xmlconfig
 
 import collective.address
-import collective.dexteritytextindexer
-import collective.folderishtypes
+import collective.contentrules.mailfromfield
+import collective.taxonomy
+
+# import collective.folderishtypes
 import collective.venue
 import collective.volto.blocksfield
 import collective.volto.cookieconsent
+import collective.z3cform.datagridfield
 import design.plone.contenttypes
+import eea.api.taxonomy
 import kitconcept.seo
 import plone.app.caching
 import plone.formwidget.geolocation
 import plone.restapi
 import redturtle.bandi
+import redturtle.prenotazioni
 import redturtle.volto
 
 
@@ -29,7 +33,6 @@ class DesignPloneContenttypesLayer(RedturtleVoltoLayer):
         # The z3c.autoinclude feature is disabled in the Plone fixture base
         # layer.
         super().setUpZope(app, configurationContext)
-        self.loadZCML(package=collective.dexteritytextindexer)
         self.loadZCML(package=collective.venue)
         self.loadZCML(package=collective.volto.blocksfield)
         self.loadZCML(package=design.plone.contenttypes, context=configurationContext)
@@ -42,6 +45,9 @@ class DesignPloneContenttypesLayer(RedturtleVoltoLayer):
         )
         self.loadZCML(package=redturtle.bandi)
         self.loadZCML(package=kitconcept.seo)
+        self.loadZCML(package=eea.api.taxonomy)
+        self.loadZCML(package=collective.taxonomy)
+        self.loadZCML(package=collective.z3cform.datagridfield)
 
     def setUpPloneSite(self, portal):
         super().setUpPloneSite(portal)
@@ -66,12 +72,12 @@ DESIGN_PLONE_CONTENTTYPES_FUNCTIONAL_TESTING = FunctionalTesting(
 class DesignPloneContenttypesRestApiLayer(RedturtleVoltoRestApiLayer):
     def setUpZope(self, app, configurationContext):
         super().setUpZope(app, configurationContext)
-        self.loadZCML(package=collective.dexteritytextindexer)
         self.loadZCML(package=collective.venue)
         self.loadZCML(package=collective.volto.blocksfield)
         self.loadZCML(package=design.plone.contenttypes, context=configurationContext)
         self.loadZCML(package=plone.formwidget.geolocation)
-        self.loadZCML(name="overrides.zcml", package=design.plone.contenttypes)
+        self.loadZCML(package=eea.api.taxonomy)
+        self.loadZCML(package=collective.taxonomy)
         xmlconfig.file(
             "configure.zcml",
             design.plone.contenttypes,
@@ -80,9 +86,18 @@ class DesignPloneContenttypesRestApiLayer(RedturtleVoltoRestApiLayer):
         self.loadZCML(package=redturtle.bandi)
         self.loadZCML(package=kitconcept.seo)
 
+        # TODO: valutare un layer a parte per i test di redturtle.prenotazioni
+        self.loadZCML(package=redturtle.prenotazioni)
+        self.loadZCML(package=collective.z3cform.datagridfield)
+        self.loadZCML(package=collective.contentrules.mailfromfield)
+
+        self.loadZCML(name="overrides.zcml", package=design.plone.contenttypes)
+
     def setUpPloneSite(self, portal):
         super().setUpPloneSite(portal)
         applyProfile(portal, "design.plone.contenttypes:default")
+        # TODO: valutare un layer a parte per i test di redturtle.prenotazioni
+        applyProfile(portal, "redturtle.prenotazioni:default")
 
 
 DESIGN_PLONE_CONTENTTYPES_API_FIXTURE = DesignPloneContenttypesRestApiLayer()
