@@ -1,24 +1,22 @@
 # -*- coding: utf-8 -*-
 
 """Setup tests for this package."""
-from plone import api
-from plone.app.testing import (
-    SITE_OWNER_NAME,
-    SITE_OWNER_PASSWORD,
-    TEST_USER_ID,
-    setRoles,
-)
-from plone.restapi.testing import RelativeSession
 from design.plone.contenttypes.testing import (
     DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING,
 )
+from plone import api
+from plone.app.testing import setRoles
+from plone.app.testing import SITE_OWNER_NAME
+from plone.app.testing import SITE_OWNER_PASSWORD
+from plone.app.testing import TEST_USER_ID
+from plone.restapi.testing import RelativeSession
 
 import unittest
 
 
 class TestDescrizioneEstesaBehavior(unittest.TestCase):
-
     layer = DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING
+    maxDiff = None
 
     def setUp(self):
         self.app = self.layer["app"]
@@ -34,7 +32,6 @@ class TestDescrizioneEstesaBehavior(unittest.TestCase):
         self.api_session.close()
 
     def test_descrizione_estesa_indexed(self):
-
         # Servizio have design.plone.contenttypes.behavior.descrizione_estesa
         # behavior
         servizio = api.content.create(
