@@ -2,23 +2,26 @@
 
 from design.plone.contenttypes.testing import (
     DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING,
+)
+from design.plone.contenttypes.testing import (
     DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
 )
+from plone import api
 from plone.app.testing import setRoles
 from plone.app.testing import SITE_OWNER_NAME
 from plone.app.testing import SITE_OWNER_PASSWORD
 from plone.app.testing import TEST_USER_ID
-from plone.restapi.testing import RelativeSession
-from plone import api
 from plone.namedfile.file import NamedBlobFile
+from plone.restapi.testing import RelativeSession
 
-import unittest
-import transaction
 import os
+import transaction
+import unittest
 
 
 class TestDocument(unittest.TestCase):
     layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING
+    maxDiff = None
 
     def setUp(self):
         """Custom shared utility setup for tests."""
@@ -42,9 +45,15 @@ class TestDocument(unittest.TestCase):
                 "design.plone.contenttypes.behavior.argomenti_documento",
                 "design.plone.contenttypes.behavior.descrizione_estesa_documento",  # noqa
                 "design.plone.contenttypes.behavior.additional_help_infos",
-                "collective.dexteritytextindexer",
+                "plone.textindexer",
                 "plone.translatable",
                 "kitconcept.seo",
+                "plone.versioning",
+                "collective.taxonomy.generated.person_life_events",
+                "collective.taxonomy.generated.business_events",
+                "collective.taxonomy.generated.tipologia_documenti_albopretorio",
+                "collective.taxonomy.generated.tipologia_documento",
+                "collective.taxonomy.generated.tipologia_licenze",
             ),
         )
 
@@ -57,7 +66,6 @@ class TestDocument(unittest.TestCase):
 
 
 class TestDocumentoApi(unittest.TestCase):
-
     layer = DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING
 
     def setUp(self):
@@ -85,7 +93,7 @@ class TestDocumentoApi(unittest.TestCase):
                 type="Modulo",
                 title="File {}".format(i),
             )
-            filename = os.path.join(os.path.dirname(__file__), u"example.pdf")
+            filename = os.path.join(os.path.dirname(__file__), "example.pdf")
             child.file = NamedBlobFile(
                 data=open(filename, "rb").read(),
                 filename="example.pdf",
