@@ -1,23 +1,27 @@
 # -*- coding: utf-8 -*-
+from design.plone.contenttypes.schema_overrides import SchemaTweaks
+from design.plone.contenttypes.testing import (
+    DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING,
+)
 from design.plone.contenttypes.testing import (
     DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
-    DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING,
 )
 from plone import api
 from plone.app.testing import setRoles
 from plone.app.testing import SITE_OWNER_NAME
 from plone.app.testing import SITE_OWNER_PASSWORD
 from plone.app.testing import TEST_USER_ID
-from plone.restapi.testing import RelativeSession
-from design.plone.contenttypes.schema_overrides import SchemaTweaks
-from zope.component import provideAdapter
 from plone.autoform.interfaces import IFormFieldProvider
+from plone.restapi.testing import RelativeSession
+from zope.component import provideAdapter
+
 import transaction
 import unittest
 
 
 class TestEvent(unittest.TestCase):
     layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING
+    maxDiff = None
 
     def setUp(self):
         """Custom shared utility setup for tests."""
@@ -31,7 +35,7 @@ class TestEvent(unittest.TestCase):
                 "plone.eventbasic",
                 "plone.leadimage",
                 "volto.preview_image",
-                "design.plone.contenttypes.behavior.argomenti",
+                "design.plone.contenttypes.behavior.argomenti_evento",
                 "plone.eventrecurrence",
                 "design.plone.contenttypes.behavior.additional_help_infos",
                 "design.plone.contenttypes.behavior.evento",
@@ -39,6 +43,7 @@ class TestEvent(unittest.TestCase):
                 "design.plone.contenttypes.behavior.address_event",
                 "design.plone.contenttypes.behavior.geolocation_event",
                 "design.plone.contenttypes.behavior.strutture_correlate",
+                "design.plone.contenttypes.behavior.contatti_event",
                 "plone.dublincore",
                 "plone.namefromtitle",
                 "plone.allowdiscussion",
@@ -48,9 +53,10 @@ class TestEvent(unittest.TestCase):
                 "plone.versioning",
                 "plone.locking",
                 "plone.constraintypes",
-                "collective.dexteritytextindexer",
+                "plone.textindexer",
                 "plone.translatable",
                 "kitconcept.seo",
+                "collective.taxonomy.generated.tipologia_evento",
             ),
         )
 
@@ -63,7 +69,6 @@ class TestEvent(unittest.TestCase):
 
 
 class TestEventApi(unittest.TestCase):
-
     layer = DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING
 
     def setUp(self):
@@ -88,13 +93,13 @@ class TestEventApi(unittest.TestCase):
         event = self.portal["evento"]
 
         self.assertEqual(
-            sorted(["multimedia", "documenti", "sponsor_evento"]),
+            sorted(["documenti", "immagini", "sponsor_evento", "video"]),
             sorted(event.keys()),
         )
 
-        self.assertEqual(event["multimedia"].portal_type, "Document")
-        self.assertEqual(event["multimedia"].constrain_types_mode, 1)
-        self.assertEqual(event["multimedia"].locally_allowed_types, ("Image", "Link"))
+        self.assertEqual(event["immagini"].portal_type, "Document")
+        self.assertEqual(event["immagini"].constrain_types_mode, 1)
+        self.assertEqual(event["immagini"].locally_allowed_types, ("Image", "Link"))
 
         self.assertEqual(event["sponsor_evento"].portal_type, "Document")
         self.assertEqual(event["sponsor_evento"].constrain_types_mode, 1)
@@ -104,10 +109,13 @@ class TestEventApi(unittest.TestCase):
         self.assertEqual(event["documenti"].constrain_types_mode, 1)
         self.assertEqual(event["documenti"].locally_allowed_types, ("File",))
 
-        multimedia_wf = api.content.get_state(obj=event["multimedia"])
-        sponsor_wf = api.content.get_state(obj=event["sponsor_evento"])
-        documenti_wf = api.content.get_state(obj=event["documenti"])
+        self.assertEqual(event["video"].portal_type, "Document")
+        self.assertEqual(event["video"].constrain_types_mode, 1)
+        self.assertEqual(event["video"].locally_allowed_types, ("Link",))
 
-        self.assertEqual(multimedia_wf, "published")
-        self.assertEqual(sponsor_wf, "published")
-        self.assertEqual(documenti_wf, "published")
+        self.assertEqual(api.content.get_state(obj=event["immagini"]), "published")
+        self.assertEqual(api.content.get_state(obj=event["video"]), "published")
+        self.assertEqual(
+            api.content.get_state(obj=event["sponsor_evento"]), "published"
+        )
+        self.assertEqual(api.content.get_state(obj=event["documenti"]), "published")
