@@ -15,13 +15,13 @@ from plone.restapi.testing import RelativeSession
 
 import unittest
 
+
 WIDGET_PROPERTY_CHECKS = {
     "tassonomia_argomenti": {
         "maximumSelectionSize": 20,
         "selectableTypes": ["Pagina Argomento"],
     },
     "ufficio_responsabile": {
-        "maximumSelectionSize": 10,
         "selectableTypes": ["UnitaOrganizzativa"],
     },
     "area": {
@@ -45,6 +45,7 @@ WIDGET_PROPERTY_CHECKS = {
 
 class TestServizio(unittest.TestCase):
     layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING
+    maxDiff = None
 
     def setUp(self):
         """Custom shared utility setup for tests."""
@@ -69,11 +70,15 @@ class TestServizio(unittest.TestCase):
                 "plone.leadimage",
                 "volto.preview_image",
                 "plone.relateditems",
-                "design.plone.contenttypes.behavior.argomenti",
+                "design.plone.contenttypes.behavior.argomenti_servizio",
                 "design.plone.contenttypes.behavior.additional_help_infos",
-                "collective.dexteritytextindexer",
+                "design.plone.contenttypes.behavior.contatti_servizio",
+                "plone.textindexer",
                 "plone.translatable",
                 "kitconcept.seo",
+                "plone.versioning",
+                "collective.taxonomy.generated.person_life_events",
+                "collective.taxonomy.generated.business_events",
             ),
         )
 
@@ -123,7 +128,6 @@ class TestServizioApi(unittest.TestCase):
         self.assertEqual(res[0].UID, servizio.UID())
 
     def test_a_chi_si_rivolge_indexed_in_searchabletext(self):
-
         #  Servizio is the only ct with this field
         servizio = api.content.create(
             container=self.portal,
@@ -138,7 +142,6 @@ class TestServizioApi(unittest.TestCase):
         self.assertEqual(res[0].UID, servizio.UID())
 
     def test_chi_puo_presentare_indexed_in_searchabletext(self):
-
         #  Servizio is the only ct with this field
         servizio = api.content.create(
             container=self.portal,
@@ -153,7 +156,6 @@ class TestServizioApi(unittest.TestCase):
         self.assertEqual(res[0].UID, servizio.UID())
 
     def test_come_si_fa_indexed_in_searchabletext(self):
-
         #  Servizio is the only ct with this field
         servizio = api.content.create(
             container=self.portal,
@@ -168,7 +170,6 @@ class TestServizioApi(unittest.TestCase):
         self.assertEqual(res[0].UID, servizio.UID())
 
     def test_cosa_si_ottiene_indexed_in_searchabletext(self):
-
         #  Servizio is the only ct with this field
         servizio = api.content.create(
             container=self.portal,
@@ -183,7 +184,6 @@ class TestServizioApi(unittest.TestCase):
         self.assertEqual(res[0].UID, servizio.UID())
 
     def test_cosa_serve_indexed_in_searchabletext(self):
-
         #  Servizio is the only ct with this field
         servizio = api.content.create(
             container=self.portal,
@@ -198,7 +198,6 @@ class TestServizioApi(unittest.TestCase):
         self.assertEqual(res[0].UID, servizio.UID())
 
     def test_ulteriori_informazioni_indexed_in_searchabletext(self):
-
         #  Servizio is the only ct with this field
         servizio = api.content.create(
             container=self.portal,
