@@ -5,12 +5,10 @@ from design.plone.contenttypes.testing import (
     DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING,
 )
 from plone import api
-from plone.app.testing import (
-    SITE_OWNER_NAME,
-    SITE_OWNER_PASSWORD,
-    TEST_USER_ID,
-    setRoles,
-)
+from plone.app.testing import setRoles
+from plone.app.testing import SITE_OWNER_NAME
+from plone.app.testing import SITE_OWNER_PASSWORD
+from plone.app.testing import TEST_USER_ID
 from plone.restapi.testing import RelativeSession
 from Products.CMFPlone.utils import getToolByName
 from transaction import commit
@@ -19,6 +17,7 @@ from zope.component import getUtility
 from zope.intid.interfaces import IIntIds
 from zope.schema.interfaces import IVocabularyFactory
 
+import transaction
 import unittest
 
 
@@ -26,6 +25,7 @@ class TestUO(unittest.TestCase):
     """Test that design.plone.contenttypes is properly installed."""
 
     layer = DESIGN_PLONE_CONTENTTYPES_API_FUNCTIONAL_TESTING
+    maxDiff = None
 
     def setUp(self):
         self.app = self.layer["app"]
@@ -108,14 +108,16 @@ class TestUO(unittest.TestCase):
                 "plone.leadimage",
                 "volto.preview_image",
                 "plone.relateditems",
-                "design.plone.contenttypes.behavior.address_uo",
-                "design.plone.contenttypes.behavior.geolocation_uo",
+                # "design.plone.contenttypes.behavior.address_uo",
+                # "design.plone.contenttypes.behavior.geolocation_uo",
                 "design.plone.contenttypes.behavior.contatti_uo",
                 "design.plone.contenttypes.behavior.argomenti",
-                "collective.dexteritytextindexer",
+                "plone.textindexer",
                 "design.plone.contenttypes.behavior.additional_help_infos",
                 "plone.translatable",
                 "kitconcept.seo",
+                "plone.versioning",
+                "collective.taxonomy.generated.tipologia_organizzazione",
             ),
         )
 
@@ -125,12 +127,6 @@ class TestUO(unittest.TestCase):
             "Unita Organizzativa", portal_types["UnitaOrganizzativa"].title
         )
 
-    def test_uo_service_related_news(self):
-        response = self.api_session.get(self.uo.absolute_url() + "?fullobjects")
-        self.assertTrue(
-            response.json()["related_news"][0]["@id"], self.news.absolute_url()
-        )
-
     def test_uo_service_related_service_show_only_services(self):
         response = self.api_session.get(self.uo.absolute_url() + "?fullobjects")
         self.assertEqual(
@@ -160,7 +156,7 @@ class TestUO(unittest.TestCase):
             "riferimento_pec_struttura",
         ]
         for field in fields:
-            self.assertEqual(sede[field], getattr(self.luogo, field, ""))
+            self.assertEqual(sede[field], getattr(self.luogo, field, None))
 
     def test_uo_location_indexer_populated(self):
         pc = api.portal.get_tool(name="portal_catalog")
@@ -213,12 +209,14 @@ class TestUO(unittest.TestCase):
 
     def test_do_not_show_parent_uo_if_not_present(self):
         response = self.api_session.get(self.uo.absolute_url())
+        self.assertEqual(response.status_code, 200)
         uo_parent = response.json()["uo_parent"]
 
         self.assertIsNone(uo_parent)
 
     def test_show_parent_uo_if_present(self):
         response = self.api_session.get(self.uo_child.absolute_url())
+        self.assertEqual(response.status_code, 200)
         uo_parent = response.json()["uo_parent"]
 
         self.assertIsNotNone(uo_parent)
@@ -230,12 +228,14 @@ class TestUO(unittest.TestCase):
 
     def test_do_not_show_children_uo_if_not_present(self):
         response = self.api_session.get(self.uo_child.absolute_url())
+        self.assertEqual(response.status_code, 200)
         uo_children = response.json()["uo_children"]
 
         self.assertEqual(uo_children, [])
 
     def test_show_children_uo_if_present(self):
         response = self.api_session.get(self.uo.absolute_url())
+        self.assertEqual(response.status_code, 200)
         uo_children = response.json()["uo_children"]
 
         self.assertEqual(len(uo_children), 1)
@@ -244,3 +244,19 @@ class TestUO(unittest.TestCase):
         self.assertEqual(uo_children[0]["city"], self.uo_child.city)
         self.assertEqual(uo_children[0]["contact_info"], self.uo_child.contact_info)
         self.assertEqual(uo_children[0]["street"], self.uo_child.street)
+
+    def test_backref_to_servizio_dove_rivolgersi(self):
+        """Check backref to servizio in
+        dove rivolgersi field"""
+
+        self.service.dove_rivolgersi = [RelationValue(self.intids.getId(self.uo))]
+
+        self.service.reindexObject()
+        transaction.commit()
+
+        response = self.api_session.get(self.uo.absolute_url())
+        self.assertEqual(response.status_code, 200)
+        self.assertIn(
+            self.service.absolute_url(),
+            [i["@id"] for i in response.json()["prestazioni"]],
+        )
