@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """Setup tests for this package."""
+from design.plone.contenttypes.controlpanels.settings import IDesignPloneSettings
 from design.plone.contenttypes.testing import (
     DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
 )
-from design.plone.contenttypes.controlpanels.settings import IDesignPloneSettings
 from plone import api
 from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
@@ -32,7 +32,16 @@ class TestSetup(unittest.TestCase):
 
     def test_product_installed(self):
         """Test if design.plone.contenttypes is installed."""
-        self.assertTrue(self.installer.isProductInstalled("design.plone.contenttypes"))
+        if hasattr(self.installer, "is_product_installed"):
+            # Plone 6
+            self.assertTrue(
+                self.installer.is_product_installed("design.plone.contenttypes")
+            )
+        else:
+            # Plone 5
+            self.assertTrue(
+                self.installer.isProductInstalled("design.plone.contenttypes")
+            )
 
     def test_browserlayer(self):
         """Test that IDesignPloneContenttypesLayer is registered."""
@@ -49,7 +58,6 @@ class TestSetup(unittest.TestCase):
 
 
 class TestUninstall(unittest.TestCase):
-
     layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING
 
     def setUp(self):
@@ -60,12 +68,26 @@ class TestUninstall(unittest.TestCase):
             self.installer = api.portal.get_tool("portal_quickinstaller")
         roles_before = api.user.get_roles(TEST_USER_ID)
         setRoles(self.portal, TEST_USER_ID, ["Manager"])
-        self.installer.uninstallProducts(["design.plone.contenttypes"])
+        if hasattr(self.installer, "uninstall_product"):
+            # Plone 6
+            self.installer.uninstall_product("design.plone.contenttypes")
+        else:
+            # Plone 5
+            self.installer.uninstallProducts(["design.plone.contenttypes"])
         setRoles(self.portal, TEST_USER_ID, roles_before)
 
     def test_product_uninstalled(self):
         """Test if design.plone.contenttypes is cleanly uninstalled."""
-        self.assertFalse(self.installer.isProductInstalled("design.plone.contenttypes"))
+        if hasattr(self.installer, "is_product_installed"):
+            # Plone 6
+            self.assertFalse(
+                self.installer.is_product_installed("design.plone.contenttypes")
+            )
+        else:
+            # Plone 5
+            self.assertFalse(
+                self.installer.isProductInstalled("design.plone.contenttypes")
+            )
 
     def test_browserlayer_removed(self):
         """Test that IDesignPloneContenttypesLayer is removed."""
